# Generic macros
#---------------
%define name castor
%define version 2.1.8
%define release 10

# Conditional packaging a-la-RPM
#-------------------------------
%ifarch x86_64
%define LIB lib64
%define FLAVOR gcc64dbg
%else
%define LIB lib
%define FLAVOR gcc32dbg
%endif

# ORACLE definitions
#-------------------
%{expand:%define has_oracle_home %(if [ -z $ORACLE_HOME ]; then echo 0; else echo 1; fi)}
%if ! %has_oracle_home
%{expand:%define has_oracle_home %([ -r /etc/sysconfig/castor ] && . /etc/sysconfig/castor; if [ -z $ORACLE_HOME ]; then echo 0; else echo 1; fi)}
%endif
%if ! %has_oracle_home
%define has_oracle 0
%else
%{expand:%define has_oracle %(if [ ! -r $ORACLE_HOME/lib/libclntsh.so ]; then echo 0; else echo 1; fi)}
%endif

# STK definitions
#----------------
%{expand:%define compiling_nostk %(if [ -z $CASTOR_NOSTK ]; then echo 0; else echo 1; fi)}
%{expand:%define has_stk_ssi %(rpm -q stk-ssi-devel >&/dev/null && rpm -q stk-ssi >&/dev/null; if [ $? -ne 0 ]; then echo 0; else echo 1; fi)}

# LSF definitions
#----------------
%{expand:%define has_lsf %(if [ -e /usr/%{LIB}/liblsf.so -a -d /usr/include/lsf ]; then echo 1; else echo 0; fi)}

# Globus defintions
#------------------
%{expand:%define has_globus_location %(if [ -z $GLOBUS_LOCATION ]; then echo 0; else echo 1; fi)}
%if ! %has_globus_location
# Try some defaults
%{expand:%define has_globus %(if [ ! -r /opt/globus/lib/libglobus_ftp_control_%{FLAVOR}.so ]; then echo 0; else echo 1; fi)}
%else
%{expand:%define has_globus %(if [ ! -r $GLOBUS_LOCATION/lib/libglobus_ftp_control_%{FLAVOR}.so ]; then echo 0; else echo 1; fi)}
%endif
%if %has_globus
%{expand:%define has_globus %(if [ ! -d $GLOBUS_LOCATION/include -a ! -d /opt/globus/include ]; then echo 0; else echo 1; fi)}
%endif

# Python definitions
#-------------------
%define _python_lib %(python -c "from distutils import sysconfig; print sysconfig.get_python_lib()")

# General settings
#-----------------
Summary: Cern Advanced mass STORage
Name: %{name}
Version: %{version}
Release: %{release}
Source0: %{name}-%{version}.tar.gz
URL: http://cern.ch/castor
License: http://cern.ch/castor/DIST/CONDITIONS
Group: Application/Castor
BuildRoot: %{_builddir}/%{name}-%{version}-root

# RPM specific definitions
#-------------------------
# Should unpackaged files in a build root terminate a build?
%define __check_files %{nil}
# Don't build debuginfo packages
%define debug_package %{nil}
# Prevents binaries stripping
%define __spec_install_post %{nil}
# Falls back to original find_provides and find_requires
%define _use_internal_dependency_generator 0

%description
The CASTOR Project stands for CERN Advanced STORage Manager, and its goal is to handle LHC data in a fully distributed environment.
%prep
%setup -q
%build
# In case makedepend is not in the PATH
PATH=${PATH}:/usr/X11R6/bin
export PATH
# define castor version (modified by maketar.sh to put the exact version)
MAJOR_CASTOR_VERSION=2.1
MINOR_CASTOR_VERSION=8.10
export MAJOR_CASTOR_VERSION
export MINOR_CASTOR_VERSION
# Don't compile ORACLE related packages if ORACLE is not present
%if ! %has_oracle
echo "### Warning, no ORACLE environment"
echo "The following packages will NOT be built:"
echo "castor-devel-oracle, castor-dlf-server, castor-lib-oracle, castor-lsf-plugin, castor-ns-server, castor-rh-server, castor-repack-server, castor-rtcopy-clientserver, castor-stager-server, castor-upv-server, castor-vmgr-server, castor-rmmaster-server, castor-jobmanager-server castor-lib-policy castor-mighunter-server"
for this in BuildCupvDaemon BuildDlfDaemon BuildNameServerDaemon BuildRHCpp BuildRepack BuildRtcpclientd BuildSchedPlugin BuildVolumeMgrDaemon UseOracle UseScheduler BuildOraCpp BuildStageDaemonCpp BuildVDQMCpp BuildDbTools BuildRmMasterCpp BuildJobManagerCpp BuildInfoPolicyLibrary BuildMigHunterDaemon BuildRecHandlerDaemon; do
	perl -pi -e "s/$this(?: |\t)+.*(YES|NO)/$this\tNO/g" config/site.def
done
%else
if [ -z "${ORACLE_HOME}" ]; then
  [ -r /etc/sysconfig/castor ] && . /etc/sysconfig/castor
fi
%endif
%if ! %has_lsf
echo "### Warning, no LSF environment"
echo "The following packages will NOT be built:"
echo "castor-lsf-plugin, castor-rmmaster-server, castor-jobmanager-server"
for this in BuildSchedPlugin BuildRmMasterCpp BuildJobManagerCpp BuildJob; do
	perl -pi -e "s/$this(?: |\t)+.*(YES|NO)/$this\tNO/g" config/site.def
done
%endif
%if ! %has_stk_ssi && ! %compiling_nostk
echo "### Warning, no STK environment"
echo "The following packages will NOT be built:"
echo "castor-tape-server"
for this in BuildTapeDaemon; do
	perl -pi -e "s/$this(?: |\t)+.*(YES|NO)/$this\tNO/g" config/site.def
done
%endif
%if %compiling_nostk
echo "### Warning, compiling only castor-tape-server-nostk"
for this in BuildCommands BuildCupvClient BuildCupvDaemon BuildCupvLibrary BuildDlfDaemon BuildDlfLibrary BuildDlfWeb BuildExpertClient BuildExpertDaemon BuildExpertLibrary BuildGCCpp BuildHsmTools BuildJobManagerCpp BuildNameServerClient BuildNameServerDaemon BuildNameServerLibrary BuildRHCpp BuildRfioClient BuildRfioLibrary BuildRfioServer BuildRmMasterCpp BuildRmNodeCpp BuildRmcLibrary BuildRmcServer BuildRtcopyClient BuildRtcopyServer BuildRtcpclientd BuildRtstat BuildSchedPlugin BuildSecureCns BuildSecureCupv BuildSecureRfio BuildSecureRtcopy BuildSecureStage BuildSecureTape BuildSecureVdqm BuildSecureVmgr BuildStageClient BuildStageClientOld BuildStageDaemonCpp BuildTapeClient BuildTapeLibrary BuildTpusage BuildVdqmClient BuildVdqmLibrary BuildVolumeMgrClient BuildVolumeMgrDaemon BuildVolumeMgrLibrary BuildVDQMCpp BuildRepack BuildMigHunterDaemon BuildRecHandlerDaemon BuildInfoPolicyLibrary BuildGridFTP HasCDK; do
	perl -pi -e "s/$this(?: |\t)+.*(YES|NO)/$this\tNO/g" config/site.def
done
%endif
%if ! %has_globus
echo "### Warning, no GLOBUS environment"
echo "The following packages will NOT be built:"
echo "castor-gridftp-dsi-int, castor-gridftp-dsi-ext, castor-gridftp-dsi-common"
for this in BuildGridFTP; do
	perl -pi -e "s/$this(?: |\t)+.*(YES|NO)/$this\tNO/g" config/site.def
done
%endif
find . -type f -exec touch {} \;
make -f Makefile.ini Makefiles
which makedepend >& /dev/null
[ $? -eq 0 ] && make depend
(cd h; ln -s . shift)
make
make
%install
# define castor version (modified by maketar.sh to put the exact version)
MAJOR_CASTOR_VERSION=2.1
MINOR_CASTOR_VERSION=8.10
export MAJOR_CASTOR_VERSION
export MINOR_CASTOR_VERSION
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}/usr/bin
mkdir -p ${RPM_BUILD_ROOT}/usr/sbin
mkdir -p ${RPM_BUILD_ROOT}/usr/%{LIB}/rtcopy
mkdir -p ${RPM_BUILD_ROOT}/%{_python_lib}
mkdir -p ${RPM_BUILD_ROOT}/usr/lib/perl/CASTOR
mkdir -p ${RPM_BUILD_ROOT}/usr/include/shift
mkdir -p ${RPM_BUILD_ROOT}/usr/share/man/man1
mkdir -p ${RPM_BUILD_ROOT}/usr/share/man/man3
mkdir -p ${RPM_BUILD_ROOT}/usr/share/man/man4
mkdir -p ${RPM_BUILD_ROOT}/etc/castor
mkdir -p ${RPM_BUILD_ROOT}/etc/castor/expert
mkdir -p ${RPM_BUILD_ROOT}/etc/castor/policies
mkdir -p ${RPM_BUILD_ROOT}/etc/sysconfig
mkdir -p ${RPM_BUILD_ROOT}/etc/init.d
mkdir -p ${RPM_BUILD_ROOT}/etc/logrotate.d
mkdir -p ${RPM_BUILD_ROOT}/usr/lsf/%{LIB}
mkdir -p ${RPM_BUILD_ROOT}/usr/lsf/etc
mkdir -p ${RPM_BUILD_ROOT}/var/spool/dlf
mkdir -p ${RPM_BUILD_ROOT}/var/spool/expert
mkdir -p ${RPM_BUILD_ROOT}/var/spool/gc
mkdir -p ${RPM_BUILD_ROOT}/var/spool/job
mkdir -p ${RPM_BUILD_ROOT}/var/spool/jobmanager
mkdir -p ${RPM_BUILD_ROOT}/var/spool/monitor
mkdir -p ${RPM_BUILD_ROOT}/var/spool/mighunter
mkdir -p ${RPM_BUILD_ROOT}/var/spool/msg
mkdir -p ${RPM_BUILD_ROOT}/var/spool/ns
mkdir -p ${RPM_BUILD_ROOT}/var/spool/rfio
mkdir -p ${RPM_BUILD_ROOT}/var/spool/rhserver
mkdir -p ${RPM_BUILD_ROOT}/var/spool/rechandler
mkdir -p ${RPM_BUILD_ROOT}/var/spool/repack
mkdir -p ${RPM_BUILD_ROOT}/var/spool/rmc
mkdir -p ${RPM_BUILD_ROOT}/var/spool/rmmaster
mkdir -p ${RPM_BUILD_ROOT}/var/spool/rmnode
mkdir -p ${RPM_BUILD_ROOT}/var/spool/rtcopy
mkdir -p ${RPM_BUILD_ROOT}/var/spool/rtcpclientd
mkdir -p ${RPM_BUILD_ROOT}/var/spool/sacct
mkdir -p ${RPM_BUILD_ROOT}/var/spool/stager
mkdir -p ${RPM_BUILD_ROOT}/var/spool/tape
mkdir -p ${RPM_BUILD_ROOT}/var/spool/upv
mkdir -p ${RPM_BUILD_ROOT}/var/spool/vdqm
mkdir -p ${RPM_BUILD_ROOT}/var/spool/scheduler
mkdir -p ${RPM_BUILD_ROOT}/var/spool/vmgr
mkdir -p ${RPM_BUILD_ROOT}/var/log
mkdir -p ${RPM_BUILD_ROOT}/var/lib/castor
mkdir -p ${RPM_BUILD_ROOT}/var/www/html/dlf/db
mkdir -p ${RPM_BUILD_ROOT}/var/www/html/dlf/js
mkdir -p ${RPM_BUILD_ROOT}/var/www/html/dlf/images
mkdir -p ${RPM_BUILD_ROOT}/var/www/conf/dlf/
%if %has_globus
  mkdir -p ${RPM_BUILD_ROOT}/etc/xinetd.d
  install -m 644 gridftp2/external/gsiftp ${RPM_BUILD_ROOT}/etc/xinetd.d/gsiftp
%if ! %has_globus_location
  mkdir -p ${RPM_BUILD_ROOT}/opt/globus/lib
%else
  mkdir -p ${RPM_BUILD_ROOT}/${GLOBUS_LOCATION}/lib
%endif
  mkdir -p ${RPM_BUILD_ROOT}/var/spool/gridftp
%endif
make install DESTDIR=${RPM_BUILD_ROOT}
make exportman DESTDIR=${RPM_BUILD_ROOT} EXPORTMAN=${RPM_BUILD_ROOT}/usr/share/man
# Install policies
(cd clips; ../imake/imake -I../config DESTDIR=${RPM_BUILD_ROOT}; make install DESTDIR=${RPM_BUILD_ROOT})

# Install example files
for i in debian/*CONFIG; do
    install -m 640 ${i} ${RPM_BUILD_ROOT}/etc/castor/`basename ${i}`.example
done
for i in `find . -name "*.init"`; do
    install -m 755 ${i} ${RPM_BUILD_ROOT}/etc/init.d/`basename ${i} | sed 's/\.init//g'`
done
install -m 644 debian/castor.conf ${RPM_BUILD_ROOT}/etc/castor/castor.conf.example
install -m 644 debian/scheduler.py ${RPM_BUILD_ROOT}/etc/castor/policies/scheduler.py.example
install -m 644 debian/migration.py ${RPM_BUILD_ROOT}/etc/castor/policies/migration.py.example
install -m 644 debian/stream.py ${RPM_BUILD_ROOT}/etc/castor/policies/stream.py.example
install -m 644 debian/rechandler.py ${RPM_BUILD_ROOT}/etc/castor/policies/rechandler.py.example
for i in debian/*.logrotate; do
    install -m 644 ${i} ${RPM_BUILD_ROOT}/etc/logrotate.d/`basename ${i} | sed 's/\.logrotate//g'`
done
for i in `find . -name "*.sysconfig"`; do
    install -m 644 ${i} ${RPM_BUILD_ROOT}/etc/sysconfig/`basename ${i} | sed 's/\.sysconfig//g'`.example
done

%if ! %compiling_nostk

# Hardcoded package name CASTOR-client for RPM transition from castor1 to castor2
%package -n CASTOR-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-stager-clientold,castor-lib,castor-doc,castor-rtcopy-client,castor-upv-client,castor-rtcopy-messages,castor-ns-client,castor-stager-client,castor-vdqm2-client,castor-rfio-client,castor-vmgr-client,castor-devel,castor-tape-client,castor-lib-compat
%description -n CASTOR-client
castor (Cern Advanced STORage system)  Meta package for CASTOR-client from castor1 transition to castor2
%files -n CASTOR-client


# The following will be filled dynamically with the rule: make rpm, or make tar
%package -n castor-sacct
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-sacct
castor (Cern Advanced STORage system) - Contains a logrotate for accounting files
%files -n castor-sacct
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-sacct
%attr(-,root,bin) %dir /var/spool/sacct

%package -n castor-config
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-config
castor (Cern Advanced STORage system) - castor.conf example
%files -n castor-config
%defattr(-,root,root)
%attr(0644,root,bin) /etc/castor/castor.conf.example

%package -n castor-devel
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib
%description -n castor-devel
castor (Cern Advanced STORage system) - API
%files -n castor-devel
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man3/Cgetopt.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cglobals.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cgrp.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cmutex.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_access.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chmod.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chown.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_closedir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_creat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_delcomment.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_delete.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_deleteclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_enterclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getcomment.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getcwd.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getsegattrs.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_lastfseq.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_listclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_listtape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_mkdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_modifyclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_opendir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_queryclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirc.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirx.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirxc.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirxt.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rename.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_replaceseg.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rewinddir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rmdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_selectsrvr.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setatime.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setcomment.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setfsize.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setsegattrs.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_dropsegs.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_stat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_tapesum.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_umask.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_undelete.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_unlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updateseg_checksum.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updateseg_status.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updatefile_checksum.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_utime.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cpool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cpwd.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Csched.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Csetprocname.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_dmpfil.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_info.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_kill.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_label.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_mount.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_position.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_reserve.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_rls.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_rstatus.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_status.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cthread.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_add.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_check.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_delete.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_list.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_modify.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cuuid.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_init.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_write.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_regtext.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_shutdown.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/expert_receive_data.1castor
%attr(0644,root,bin) %doc /usr/share/man/man3/expert_send_data.1castor
%attr(0644,root,bin) %doc /usr/share/man/man3/expert_send_request.1castor
%attr(0644,root,bin) %doc /usr/share/man/man3/getacct.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/getacctent.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/getcompstat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/getconfent.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/log.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/netclose.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/netread.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/netwrite.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/readlbl.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_access.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_chmod.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_chown.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_close.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_closedir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fchmod.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fclose.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_feof.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ferror.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fflush.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fileno.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fopen.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fopen64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fread.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fseek.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fseeko64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fstat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fstat64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ftell.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ftello64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fwrite.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lockf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lockf64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lseek.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lseek64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lstat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lstat64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mkdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mstat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mstat64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_msymlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_munlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_open.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_open64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_opendir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_pclose.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_perror.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_popen.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_preseek.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_preseek64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_read.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_readdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_readlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rename.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rewinddir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rmdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_serror.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_stat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_stat64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_statfs.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_symlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_unlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_write.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfioreadopt.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfiosetopt.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_dismount.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_export.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_find_cartridge.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_get_geometry.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_import.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_mount.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_read_elem_status.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_seterrbuf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rwndtape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/sacct.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/serrno.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/skiptape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/usrlbl.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_Connect.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_DelDrive.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_DelVolumeReq.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_Disconnect.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_NextDrive.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_NextVol.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_SendVolReq.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_UnitStatus.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletedenmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletedgnmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletelibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletemodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletepool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletetape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deltag.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterdenmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterdgnmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterlibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_entermodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterpool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_entertape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_gettag.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_gettape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listdenmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listdgnmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listlibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listmodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listpool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listtape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifylibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifymodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifypool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifytape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querylibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querymodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querypool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querytape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_reclaim.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_seterrbuf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_settag.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_tpmounted.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_updatetape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/wrttpmrk.3castor
%attr(0644,root,bin) %doc /usr/share/man/man4/Castor_limits.4castor
%ifarch x86_64
%attr(0644,root,bin) /usr/include/shift.h
%attr(0644,root,bin) /usr/include/shift/Castor_limits.h
%attr(0644,root,bin) /usr/include/shift/Cdlopen_api.h
%attr(0644,root,bin) /usr/include/shift/Cgetopt.h
%attr(0644,root,bin) /usr/include/shift/Cglobals.h
%attr(0644,root,bin) /usr/include/shift/Cgrp.h
%attr(0644,root,bin) /usr/include/shift/Cinit.h
%attr(0644,root,bin) /usr/include/shift/Cmutex.h
%attr(0644,root,bin) /usr/include/shift/Cnetdb.h
%attr(0644,root,bin) /usr/include/shift/Cns.h
%attr(0644,root,bin) /usr/include/shift/Cns_api.h
%attr(0644,root,bin) /usr/include/shift/Cns_constants.h
%attr(0644,root,bin) /usr/include/shift/Cns_server.h
%attr(0644,root,bin) /usr/include/shift/Cns_struct.h
%attr(0644,root,bin) /usr/include/shift/Cpool_api.h
%attr(0644,root,bin) /usr/include/shift/Cpwd.h
%attr(0644,root,bin) /usr/include/shift/Cregexp.h
%attr(0644,root,bin) /usr/include/shift/Cregexp_magic.h
%attr(0644,root,bin) /usr/include/shift/Csched_api.h
%attr(0644,root,bin) /usr/include/shift/Csched_flags.h
%attr(0644,root,bin) /usr/include/shift/Csec.h
%attr(0644,root,bin) /usr/include/shift/Csec_api.h
%attr(0644,root,bin) /usr/include/shift/Csec_common.h
%attr(0644,root,bin) /usr/include/shift/Csec_constants.h
%attr(0644,root,bin) /usr/include/shift/Csec_plugin.h
%attr(0644,root,bin) /usr/include/shift/Csemaphore.h
%attr(0644,root,bin) /usr/include/shift/Csetprocname.h
%attr(0644,root,bin) /usr/include/shift/Csnprintf.h
%attr(0644,root,bin) /usr/include/shift/Cstrerror.h
%attr(0644,root,bin) /usr/include/shift/Ctape.h
%attr(0644,root,bin) /usr/include/shift/Ctape_api.h
%attr(0644,root,bin) /usr/include/shift/Ctape_constants.h
%attr(0644,root,bin) /usr/include/shift/Cthread_api.h
%attr(0644,root,bin) /usr/include/shift/Cthread_flags.h
%attr(0644,root,bin) /usr/include/shift/Cthread_typedef.h
%attr(0644,root,bin) /usr/include/shift/Cupv.h
%attr(0644,root,bin) /usr/include/shift/Cupv_api.h
%attr(0644,root,bin) /usr/include/shift/Cupv_constants.h
%attr(0644,root,bin) /usr/include/shift/Cupv_server.h
%attr(0644,root,bin) /usr/include/shift/Cupv_struct.h
%attr(0644,root,bin) /usr/include/shift/Cupv_util.h
%attr(0644,root,bin) /usr/include/shift/Cuuid.h
%attr(0644,root,bin) /usr/include/shift/RfioTURL.h
%attr(0644,root,bin) /usr/include/shift/common.h
%attr(0644,root,bin) /usr/include/shift/dlf_api.h
%attr(0644,root,bin) /usr/include/shift/dmc.h
%attr(0644,root,bin) /usr/include/shift/expert.h
%attr(0644,root,bin) /usr/include/shift/expert_api.h
%attr(0644,root,bin) /usr/include/shift/expert_constants.h
%attr(0644,root,bin) /usr/include/shift/expert_daemon.h
%attr(0644,root,bin) /usr/include/shift/getacct.h
%attr(0644,root,bin) /usr/include/shift/getacctent.h
%attr(0644,root,bin) /usr/include/shift/getconfent.h
%attr(0644,root,bin) /usr/include/shift/log.h
%attr(0644,root,bin) /usr/include/shift/marshall.h
%attr(0644,root,bin) /usr/include/shift/md5.h
%attr(0644,root,bin) /usr/include/shift/net.h
%attr(0644,root,bin) /usr/include/shift/osdep.h
%attr(0644,root,bin) /usr/include/shift/patchlevel.h
%attr(0644,root,bin) /usr/include/shift/rfcntl.h
%attr(0644,root,bin) /usr/include/shift/rfio.h
%attr(0644,root,bin) /usr/include/shift/rfio_api.h
%attr(0644,root,bin) /usr/include/shift/rfio_constants.h
%attr(0644,root,bin) /usr/include/shift/rfio_errno.h
%attr(0644,root,bin) /usr/include/shift/rfio_lcastorfdt.h
%attr(0644,root,bin) /usr/include/shift/rmc.h
%attr(0644,root,bin) /usr/include/shift/rmc_api.h
%attr(0644,root,bin) /usr/include/shift/rmc_constants.h
%attr(0644,root,bin) /usr/include/shift/rmnode_util.h
%attr(0644,root,bin) /usr/include/shift/rtcp.h
%attr(0644,root,bin) /usr/include/shift/rtcp_api.h
%attr(0644,root,bin) /usr/include/shift/rtcp_constants.h
%attr(0644,root,bin) /usr/include/shift/rtcp_server.h
%attr(0644,root,bin) /usr/include/shift/rtcpcld.h
%attr(0644,root,bin) /usr/include/shift/rtcpcld_constants.h
%attr(0644,root,bin) /usr/include/shift/rtcpcld_messages.h
%attr(0644,root,bin) /usr/include/shift/rtcpcldapi.h
%attr(0644,root,bin) /usr/include/shift/sacct.h
%attr(0644,root,bin) /usr/include/shift/scsictl.h
%attr(0644,root,bin) /usr/include/shift/serrno.h
%attr(0644,root,bin) /usr/include/shift/smc.h
%attr(0644,root,bin) /usr/include/shift/socket_timeout.h
%attr(0644,root,bin) /usr/include/shift/stage.h
%attr(0644,root,bin) /usr/include/shift/stage_api.h
%attr(0644,root,bin) /usr/include/shift/stage_constants.h
%attr(0644,root,bin) /usr/include/shift/stage_limits.h
%attr(0644,root,bin) /usr/include/shift/stage_macros.h
%attr(0644,root,bin) /usr/include/shift/stage_messages.h
%attr(0644,root,bin) /usr/include/shift/stage_protocol.h
%attr(0644,root,bin) /usr/include/shift/stage_server_struct.h
%attr(0644,root,bin) /usr/include/shift/stage_shift.h
%attr(0644,root,bin) /usr/include/shift/stage_struct.h
%attr(0644,root,bin) /usr/include/shift/stager_api.h
%attr(0644,root,bin) /usr/include/shift/stager_catalogInterface.h
%attr(0644,root,bin) /usr/include/shift/stager_client_api.h
%attr(0644,root,bin) /usr/include/shift/stager_constants.h
%attr(0644,root,bin) /usr/include/shift/stager_errmsg.h
%attr(0644,root,bin) /usr/include/shift/stager_extern_globals.h
%attr(0644,root,bin) /usr/include/shift/stager_macros.h
%attr(0644,root,bin) /usr/include/shift/stager_mapper.h
%attr(0644,root,bin) /usr/include/shift/stager_messages.h
%attr(0644,root,bin) /usr/include/shift/stager_mover_api.h
%attr(0644,root,bin) /usr/include/shift/stager_util.h
%attr(0644,root,bin) /usr/include/shift/stager_uuid.h
%attr(0644,root,bin) /usr/include/shift/trace.h
%attr(0644,root,bin) /usr/include/shift/u64subr.h
%attr(0644,root,bin) /usr/include/shift/util.h
%attr(0644,root,bin) /usr/include/shift/vdqm.h
%attr(0644,root,bin) /usr/include/shift/vdqm_api.h
%attr(0644,root,bin) /usr/include/shift/vdqm_constants.h
%attr(0644,root,bin) /usr/include/shift/vmgr.h
%attr(0644,root,bin) /usr/include/shift/vmgr_api.h
%attr(0644,root,bin) /usr/include/shift/vmgr_constants.h
%attr(0644,root,bin) /usr/include/shift/vmgr_server.h
%attr(0644,root,bin) /usr/include/shift/vmgr_struct.h
%attr(0644,root,bin) /usr/include/shift/ypgetacctent.h
%attr(-,root,root) /usr/lib64/libshift.so
%attr(-,root,root) /usr/lib64/libcastorClient.so
%attr(-,root,root) /usr/lib64/libcastorns.so
%attr(-,root,root) /usr/lib64/libcastorrfio.so
%attr(-,root,root) /usr/lib64/libcastorupv.so
%attr(-,root,root) /usr/lib64/libcastorvmgr.so
%attr(-,root,root) /usr/lib64/libcastorrtcopy.so
%attr(-,root,root) /usr/lib64/libcastorvdqm.so
%else
%attr(0644,root,bin) /usr/include/shift.h
%attr(0644,root,bin) /usr/include/shift/Castor_limits.h
%attr(0644,root,bin) /usr/include/shift/Cdlopen_api.h
%attr(0644,root,bin) /usr/include/shift/Cgetopt.h
%attr(0644,root,bin) /usr/include/shift/Cglobals.h
%attr(0644,root,bin) /usr/include/shift/Cgrp.h
%attr(0644,root,bin) /usr/include/shift/Cinit.h
%attr(0644,root,bin) /usr/include/shift/Cmutex.h
%attr(0644,root,bin) /usr/include/shift/Cnetdb.h
%attr(0644,root,bin) /usr/include/shift/Cns.h
%attr(0644,root,bin) /usr/include/shift/Cns_api.h
%attr(0644,root,bin) /usr/include/shift/Cns_constants.h
%attr(0644,root,bin) /usr/include/shift/Cns_server.h
%attr(0644,root,bin) /usr/include/shift/Cns_struct.h
%attr(0644,root,bin) /usr/include/shift/Cpool_api.h
%attr(0644,root,bin) /usr/include/shift/Cpwd.h
%attr(0644,root,bin) /usr/include/shift/Cregexp.h
%attr(0644,root,bin) /usr/include/shift/Cregexp_magic.h
%attr(0644,root,bin) /usr/include/shift/Csched_api.h
%attr(0644,root,bin) /usr/include/shift/Csched_flags.h
%attr(0644,root,bin) /usr/include/shift/Csec.h
%attr(0644,root,bin) /usr/include/shift/Csec_api.h
%attr(0644,root,bin) /usr/include/shift/Csec_common.h
%attr(0644,root,bin) /usr/include/shift/Csec_constants.h
%attr(0644,root,bin) /usr/include/shift/Csec_plugin.h
%attr(0644,root,bin) /usr/include/shift/Csemaphore.h
%attr(0644,root,bin) /usr/include/shift/Csetprocname.h
%attr(0644,root,bin) /usr/include/shift/Csnprintf.h
%attr(0644,root,bin) /usr/include/shift/Cstrerror.h
%attr(0644,root,bin) /usr/include/shift/Ctape.h
%attr(0644,root,bin) /usr/include/shift/Ctape_api.h
%attr(0644,root,bin) /usr/include/shift/Ctape_constants.h
%attr(0644,root,bin) /usr/include/shift/Cthread_api.h
%attr(0644,root,bin) /usr/include/shift/Cthread_flags.h
%attr(0644,root,bin) /usr/include/shift/Cthread_typedef.h
%attr(0644,root,bin) /usr/include/shift/Cupv.h
%attr(0644,root,bin) /usr/include/shift/Cupv_api.h
%attr(0644,root,bin) /usr/include/shift/Cupv_constants.h
%attr(0644,root,bin) /usr/include/shift/Cupv_server.h
%attr(0644,root,bin) /usr/include/shift/Cupv_struct.h
%attr(0644,root,bin) /usr/include/shift/Cupv_util.h
%attr(0644,root,bin) /usr/include/shift/Cuuid.h
%attr(0644,root,bin) /usr/include/shift/RfioTURL.h
%attr(0644,root,bin) /usr/include/shift/common.h
%attr(0644,root,bin) /usr/include/shift/dlf_api.h
%attr(0644,root,bin) /usr/include/shift/dmc.h
%attr(0644,root,bin) /usr/include/shift/expert.h
%attr(0644,root,bin) /usr/include/shift/expert_api.h
%attr(0644,root,bin) /usr/include/shift/expert_constants.h
%attr(0644,root,bin) /usr/include/shift/expert_daemon.h
%attr(0644,root,bin) /usr/include/shift/getacct.h
%attr(0644,root,bin) /usr/include/shift/getacctent.h
%attr(0644,root,bin) /usr/include/shift/getconfent.h
%attr(0644,root,bin) /usr/include/shift/log.h
%attr(0644,root,bin) /usr/include/shift/marshall.h
%attr(0644,root,bin) /usr/include/shift/md5.h
%attr(0644,root,bin) /usr/include/shift/net.h
%attr(0644,root,bin) /usr/include/shift/osdep.h
%attr(0644,root,bin) /usr/include/shift/patchlevel.h
%attr(0644,root,bin) /usr/include/shift/rfcntl.h
%attr(0644,root,bin) /usr/include/shift/rfio.h
%attr(0644,root,bin) /usr/include/shift/rfio_api.h
%attr(0644,root,bin) /usr/include/shift/rfio_constants.h
%attr(0644,root,bin) /usr/include/shift/rfio_errno.h
%attr(0644,root,bin) /usr/include/shift/rfio_lcastorfdt.h
%attr(0644,root,bin) /usr/include/shift/rmc.h
%attr(0644,root,bin) /usr/include/shift/rmc_api.h
%attr(0644,root,bin) /usr/include/shift/rmc_constants.h
%attr(0644,root,bin) /usr/include/shift/rmnode_util.h
%attr(0644,root,bin) /usr/include/shift/rtcp.h
%attr(0644,root,bin) /usr/include/shift/rtcp_api.h
%attr(0644,root,bin) /usr/include/shift/rtcp_constants.h
%attr(0644,root,bin) /usr/include/shift/rtcp_server.h
%attr(0644,root,bin) /usr/include/shift/rtcpcld.h
%attr(0644,root,bin) /usr/include/shift/rtcpcld_constants.h
%attr(0644,root,bin) /usr/include/shift/rtcpcld_messages.h
%attr(0644,root,bin) /usr/include/shift/rtcpcldapi.h
%attr(0644,root,bin) /usr/include/shift/sacct.h
%attr(0644,root,bin) /usr/include/shift/scsictl.h
%attr(0644,root,bin) /usr/include/shift/serrno.h
%attr(0644,root,bin) /usr/include/shift/smc.h
%attr(0644,root,bin) /usr/include/shift/socket_timeout.h
%attr(0644,root,bin) /usr/include/shift/stage.h
%attr(0644,root,bin) /usr/include/shift/stage_api.h
%attr(0644,root,bin) /usr/include/shift/stage_constants.h
%attr(0644,root,bin) /usr/include/shift/stage_limits.h
%attr(0644,root,bin) /usr/include/shift/stage_macros.h
%attr(0644,root,bin) /usr/include/shift/stage_messages.h
%attr(0644,root,bin) /usr/include/shift/stage_protocol.h
%attr(0644,root,bin) /usr/include/shift/stage_server_struct.h
%attr(0644,root,bin) /usr/include/shift/stage_shift.h
%attr(0644,root,bin) /usr/include/shift/stage_struct.h
%attr(0644,root,bin) /usr/include/shift/stager_api.h
%attr(0644,root,bin) /usr/include/shift/stager_catalogInterface.h
%attr(0644,root,bin) /usr/include/shift/stager_client_api.h
%attr(0644,root,bin) /usr/include/shift/stager_constants.h
%attr(0644,root,bin) /usr/include/shift/stager_errmsg.h
%attr(0644,root,bin) /usr/include/shift/stager_extern_globals.h
%attr(0644,root,bin) /usr/include/shift/stager_macros.h
%attr(0644,root,bin) /usr/include/shift/stager_mapper.h
%attr(0644,root,bin) /usr/include/shift/stager_messages.h
%attr(0644,root,bin) /usr/include/shift/stager_mover_api.h
%attr(0644,root,bin) /usr/include/shift/stager_util.h
%attr(0644,root,bin) /usr/include/shift/stager_uuid.h
%attr(0644,root,bin) /usr/include/shift/trace.h
%attr(0644,root,bin) /usr/include/shift/u64subr.h
%attr(0644,root,bin) /usr/include/shift/util.h
%attr(0644,root,bin) /usr/include/shift/vdqm.h
%attr(0644,root,bin) /usr/include/shift/vdqm_api.h
%attr(0644,root,bin) /usr/include/shift/vdqm_constants.h
%attr(0644,root,bin) /usr/include/shift/vmgr.h
%attr(0644,root,bin) /usr/include/shift/vmgr_api.h
%attr(0644,root,bin) /usr/include/shift/vmgr_constants.h
%attr(0644,root,bin) /usr/include/shift/vmgr_server.h
%attr(0644,root,bin) /usr/include/shift/vmgr_struct.h
%attr(0644,root,bin) /usr/include/shift/ypgetacctent.h
%attr(-,root,root) /usr/lib/libshift.so
%attr(-,root,root) /usr/lib/libcastorClient.so
%attr(-,root,root) /usr/lib/libcastorns.so
%attr(-,root,root) /usr/lib/libcastorrfio.so
%attr(-,root,root) /usr/lib/libcastorupv.so
%attr(-,root,root) /usr/lib/libcastorvmgr.so
%attr(-,root,root) /usr/lib/libcastorrtcopy.so
%attr(-,root,root) /usr/lib/libcastorvdqm.so
%endif

%if %has_oracle
%package -n castor-devel-oracle
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib-oracle
%description -n castor-devel-oracle
castor (Cern Advanced STORage system) - Oracle API
%files -n castor-devel-oracle
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastorCommonOra.so
%else
%attr(-,root,root) /usr/lib/libcastorCommonOra.so
%endif
%endif

%if %has_oracle
%package -n castor-dlf-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-dlf-server
castor (Cern Advanced STORage system) - Distributed Logging Facility server
%files -n castor-dlf-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-dlf-server
%attr(0644,root,bin) %doc /usr/share/man/man1/dlfserver.1castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_child.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_create_threads.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_init.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_isinitialized.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_parent.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_prepare.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_regtext.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_write.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_shutdown.3castor
%attr(-,root,bin) %dir /var/spool/dlf
%attr(0640,root,st) /etc/castor/DLFCONFIG.example
%attr(0644,root,bin) /etc/sysconfig/dlfserver.example
%attr(0755,root,bin) /etc/init.d/dlfserver
%attr(0750,root,bin) /usr/bin/dlfserver
%post -n castor-dlf-server
/sbin/chkconfig --add dlfserver
/sbin/service dlfserver condrestart > /dev/null 2>&1 || :
%preun -n castor-dlf-server
if [ "$1" = 0 ]; then
    /sbin/service dlfserver stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del dlfserver
fi
%endif

%package -n castor-expert-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-expert-server
castor (Cern Advanced STORage system) - Expert server, used to trigger policies
%files -n castor-expert-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-expert-server
%attr(0644,root,bin) %doc /usr/share/man/man1/expert.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/expertd.1castor
%attr(-,root,bin) %dir /var/spool/expert
%attr(0640,root,st) /etc/castor/EXPCONFIG.example
%attr(0755,root,bin) /etc/init.d/expertd
%attr(0644,root,bin) /etc/sysconfig/expertd.example
%attr(0750,root,bin) /usr/bin/expertd
%post -n castor-expert-server
/sbin/chkconfig --add expertd
/sbin/service expertd condrestart > /dev/null 2>&1 || :
%preun -n castor-expert-server
if [ "$1" = 0 ]; then
    /sbin/service expertd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del expertd
fi

%package -n castor-gc-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-gc-server
castor (Cern Advanced STORage system) - Garbage collector, running on every worker node
%files -n castor-gc-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-gc-server
%attr(0644,root,bin) %doc /usr/share/man/man1/gcDaemon.1castor
%attr(-,root,bin) %dir /var/spool/gc
%attr(0755,root,bin) /etc/init.d/gcDaemon
%attr(0644,root,bin) /etc/sysconfig/gcDaemon.example
%attr(0750,root,bin) /usr/bin/gcDaemon
%post -n castor-gc-server
/sbin/chkconfig --add gcDaemon
/sbin/service gcDaemon condrestart > /dev/null 2>&1 || :
/bin/chown stage:st /var/spool/gc
/bin/chown stage:st /var/spool/gc/log > /dev/null 2>&1
%preun -n castor-gc-server
if [ "$1" = 0 ]; then
    /sbin/service gcDaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del gcDaemon
fi

%package -n castor-hsmtools
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: cx_Oracle
%description -n castor-hsmtools
castor (Cern Advanced STORage system) - HSM Administration tools e.g. reclaim
%files -n castor-hsmtools
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/reclaim.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/c2probe.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/adler32.1castor
%attr(0755,root,bin) /usr/bin/reclaim
%attr(0755,root,bin) /usr/bin/c2probe
%attr(0755,root,bin) /usr/bin/rfcpupd
%attr(0755,root,bin) /usr/bin/adler32

%if %has_oracle
%package -n castor-dbtools
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-dbtools
castor (Cern Advanced STORage system) - DB Administration tools
%files -n castor-dbtools
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/cleanLostFiles.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/deleteFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/deleteSvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/diskServer_qry.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/draindiskserver.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/enterFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/enterSvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/listFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/listSvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/modifyFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/modifySvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/moveDiskServer.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/printFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/printSvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmDBInit.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmdeletepriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmlistpriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmlistrequest.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmsetpriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/adminMultiInstance.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/deletePriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/enterPriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/listPriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/migrateNewCopy.1castor
%attr(0755,root,bin) /usr/bin/cleanLostFiles
%attr(0755,root,bin) /usr/bin/deleteFileClass
%attr(0755,root,bin) /usr/bin/deleteSvcClass
%attr(0755,root,bin) /usr/bin/diskServer_qry
%attr(0755,root,bin) /usr/bin/draindiskserver
%attr(0755,root,bin) /usr/bin/enterFileClass
%attr(0755,root,bin) /usr/bin/enterSvcClass
%attr(0755,root,bin) /usr/bin/listFileClass
%attr(0755,root,bin) /usr/bin/listSvcClass
%attr(0755,root,bin) /usr/bin/modifyFileClass
%attr(0755,root,bin) /usr/bin/modifySvcClass
%attr(0755,root,bin) /usr/bin/moveDiskServer
%attr(0755,root,bin) /usr/bin/printFileClass
%attr(0755,root,bin) /usr/bin/printSvcClass
%attr(0755,root,bin) /usr/lib/perl/CASTOR/castor_tools.pm
%attr(0644,root,bin) /%{_python_lib}/castor_tools.py
%attr(0755,root,bin) /usr/bin/vdqmDBInit
%attr(0755,root,bin) /usr/bin/vdqmdeletepriority
%attr(0755,root,bin) /usr/bin/vdqmlistpriority
%attr(0755,root,bin) /usr/bin/vdqmlistrequest
%attr(0755,root,bin) /usr/bin/vdqmsetpriority
%attr(0755,root,bin) /usr/bin/checkreplicas
%attr(0755,root,bin) /usr/bin/deletePriority
%attr(0755,root,bin) /usr/bin/enterPriority
%attr(0755,root,bin) /usr/bin/listPriority
%attr(0755,root,root) /usr/bin/migrateNewCopy
%endif

%if %has_lsf
%package -n castor-job
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-job
castor (Cern Advanced STORage system) - The job giving user access to data on the worder nodes
%files -n castor-job
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-job
%attr(-,root,bin) %dir /var/spool/job
%attr(6755,stage,st) /usr/bin/stagerJob
%attr(6755,stage,st) /usr/bin/diskCopyTransfer
%post -n castor-job
/bin/chown stage:st /var/spool/job
/bin/chmod 755 /var/spool/job
%endif

%if %has_oracle
%if %has_lsf
%package -n castor-jobmanager-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-jobmanager-server
castor (Cern Advanced STORage system) - The Job Manager server used to submit jobs into the scheduler
%files -n castor-jobmanager-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-jobmanager-server
%attr(0644,root,bin) %doc /usr/share/man/man1/jobManager.1castor
%attr(-,root,bin) %dir /var/spool/jobmanager
%attr(0755,root,bin) /etc/init.d/jobManager
%attr(0644,root,bin) /etc/sysconfig/jobManager.example
%attr(0750,root,bin) /usr/bin/jobManager
%post -n castor-jobmanager-server
/sbin/chkconfig --add jobManager
/sbin/service jobManager condrestart > /dev/null 2>&1 || :
%preun -n castor-jobmanager-server
if [ "$1" = 0 ]; then
    /sbin/service jobManager stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del jobManager
fi
%endif
%endif

%package -n castor-lib
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-lib
castor (Cern Advanced STORage system) - Static and shared libraries for end-users
%files -n castor-lib
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libshift.so.2.1
%attr(-,root,root) /usr/lib64/libshift.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libcastorClient.so.2.1
%attr(-,root,root) /usr/lib64/libcastorClient.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libcastorns.so.2.1
%attr(-,root,root) /usr/lib64/libcastorns.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libcastorrfio.so.2.1
%attr(-,root,root) /usr/lib64/libcastorrfio.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libcastorupv.so.2.1
%attr(-,root,root) /usr/lib64/libcastorupv.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libcastorvmgr.so.2.1
%attr(-,root,root) /usr/lib64/libcastorvmgr.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libcastorrtcopy.so.2.1
%attr(-,root,root) /usr/lib64/libcastorrtcopy.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libcastorvdqm.so.2.1
%attr(-,root,root) /usr/lib64/libcastorvdqm.so.2.1.8.10
%else
%attr(-,root,root) /usr/lib/libshift.so.2.1
%attr(-,root,root) /usr/lib/libshift.so.2.1.8.10
%attr(-,root,root) /usr/lib/libcastorClient.so.2.1
%attr(-,root,root) /usr/lib/libcastorClient.so.2.1.8.10
%attr(-,root,root) /usr/lib/libcastorns.so.2.1
%attr(-,root,root) /usr/lib/libcastorns.so.2.1.8.10
%attr(-,root,root) /usr/lib/libcastorrfio.so.2.1
%attr(-,root,root) /usr/lib/libcastorrfio.so.2.1.8.10
%attr(-,root,root) /usr/lib/libcastorupv.so.2.1
%attr(-,root,root) /usr/lib/libcastorupv.so.2.1.8.10
%attr(-,root,root) /usr/lib/libcastorvmgr.so.2.1
%attr(-,root,root) /usr/lib/libcastorvmgr.so.2.1.8.10
%attr(-,root,root) /usr/lib/libcastorrtcopy.so.2.1
%attr(-,root,root) /usr/lib/libcastorrtcopy.so.2.1.8.10
%attr(-,root,root) /usr/lib/libcastorvdqm.so.2.1
%attr(-,root,root) /usr/lib/libcastorvdqm.so.2.1.8.10
%endif
%post -n castor-lib
# IP tables modification to allow the castor client to open ports
if [ -e /etc/sysconfig/iptables ]; then
  if ! /bin/grep -q 'controlled by CASTOR-client RPM' /etc/sysconfig/iptables; then
    /bin/cat <<EOFiptable |\
/bin/sed -i.castor -e '/-A RH-Firewall-1-INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT/r /dev/stdin' /etc/sysconfig/iptables
# controlled by CASTOR-client RPM 
# allow callbacks for RFIO, port range corresponds to default callback range
-A RH-Firewall-1-INPUT -m state --state NEW -m tcp -p tcp --dport 30000:30100 -j ACCEPT
# end of CASTOR-client RPM modifications
EOFiptable
    /sbin/service iptables condrestart > /dev/null 2>&1 || :
  fi
fi
/sbin/ldconfig
%postun -n castor-lib
# IP tables modification to allow the castor client to open ports
if [ -e /etc/sysconfig/iptables ]; then
    /bin/sed -i.castor -e '/controlled by CASTOR-client RPM/,/end of CASTOR-client RPM modifications/d' /etc/sysconfig/iptables
    /sbin/service iptables condrestart > /dev/null 2>&1 || :
fi
/sbin/ldconfig

%if %has_oracle
%if %has_lsf
%package -n castor-lsf-plugin
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python
%description -n castor-lsf-plugin
castor (Cern Advanced STORage system) - Scheduler plugin for LSF (6.1 minimum) framework
%files -n castor-lsf-plugin
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-lsf-plugin
%attr(0644,root,bin) %doc /usr/share/man/man1/schmod_castor.1castor
%attr(-,root,bin) %dir /var/spool/scheduler
%ifarch x86_64
%attr(0755,root,bin) /usr/lib64/schmod_shmem.so
%attr(0755,root,bin) /usr/lib64/schmod_python.so
%attr(0644,root,bin) /etc/castor/policies/scheduler.py.example
%else
%attr(0755,root,bin) /usr/lib/schmod_shmem.so
%attr(0755,root,bin) /usr/lib/schmod_python.so
%attr(0644,root,bin) /etc/castor/policies/scheduler.py.example
%endif
%post -n castor-lsf-plugin
/bin/chmod 775 /var/spool/scheduler
%endif
%endif

%if %has_oracle
%package -n castor-lib-oracle
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-lib-oracle
castor (Cern Advanced STORage system) - Static and shared libraries for Oracle access
%files -n castor-lib-oracle
%defattr(-,root,root)
%ifarch x86_64
%attr(0640,root,root) /etc/castor/ORASTAGERCONFIG.example
%attr(-,root,root) /usr/lib64/libcastorCommonOra.so.2.1
%attr(-,root,root) /usr/lib64/libcastorCommonOra.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libcastorCnvs.so.2.1
%attr(-,root,root) /usr/lib64/libcastorCnvs.so.2.1.8.10
%else
%attr(0640,root,root) /etc/castor/ORASTAGERCONFIG.example
%attr(-,root,root) /usr/lib/libcastorCommonOra.so.2.1
%attr(-,root,root) /usr/lib/libcastorCommonOra.so.2.1.8.10
%attr(-,root,root) /usr/lib/libcastorCnvs.so.2.1
%attr(-,root,root) /usr/lib/libcastorCnvs.so.2.1.8.10
%endif
%post -n castor-lib-oracle -p /sbin/ldconfig
%postun -n castor-lib-oracle -p /sbin/ldconfig
%endif

%package -n castor-ns-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-ns-client
castor (Cern Advanced STORage system) - Name server clients
%files -n castor-ns-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/nschclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nschmod.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nschown.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdelcomment.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdeleteclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsenterclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsfind.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsgetacl.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsgetpath.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nslistclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nslisttape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsln.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsls.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsmkdir.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsmodifyclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsping.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrename.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrm.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrmdir.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetacl.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetchecksum.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetcomment.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetfsize.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetsegment.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nstouch.1castor
%attr(0755,root,bin) /usr/bin/nschclass
%attr(0755,root,bin) /usr/bin/nschmod
%attr(0755,root,bin) /usr/bin/nschown
%attr(0755,root,bin) /usr/bin/nsdelcomment
%attr(0755,root,bin) /usr/bin/nsdeleteclass
%attr(0755,root,bin) /usr/bin/nsenterclass
%attr(0755,root,bin) /usr/bin/nsfind
%attr(0755,root,bin) /usr/bin/nsgetacl
%attr(0755,root,bin) /usr/bin/nsgetpath
%attr(0755,root,bin) /usr/bin/nslistclass
%attr(0755,root,bin) /usr/bin/nslisttape
%attr(0755,root,bin) /usr/bin/nsln
%attr(0755,root,bin) /usr/bin/nsls
%attr(0755,root,bin) /usr/bin/nsmkdir
%attr(0755,root,bin) /usr/bin/nsmodifyclass
%attr(0755,root,bin) /usr/bin/nsping
%attr(0755,root,bin) /usr/bin/nsrename
%attr(0755,root,bin) /usr/bin/nsrm
%attr(0755,root,bin) /usr/bin/nsrmdir
%attr(0755,root,bin) /usr/bin/nssetchecksum
%attr(0755,root,bin) /usr/bin/nssetacl
%attr(0755,root,bin) /usr/bin/nssetcomment
%attr(0755,root,bin) /usr/bin/nssetfsize
%attr(0755,root,bin) /usr/bin/nssetsegment
%attr(0755,root,bin) /usr/bin/nstouch

%if %has_oracle
%package -n castor-ns-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,vdt_globus_essentials
%description -n castor-ns-server
castor (Cern Advanced STORage system) - Name server daemon
%files -n castor-ns-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-ns-server
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdaemon.1castor
%attr(-,root,bin) %dir /var/spool/ns
%attr(0640,root,st) /etc/castor/NSCONFIG.example
%attr(0755,root,bin) /etc/init.d/nsdaemon
%attr(0644,root,bin) /etc/sysconfig/nsdaemon.example
%attr(0750,root,bin) /usr/bin/nsdaemon
%post -n castor-ns-server
/sbin/chkconfig --add nsdaemon
/sbin/service nsdaemon condrestart > /dev/null 2>&1 || :
%preun -n castor-ns-server
if [ "$1" = 0 ]; then
    /sbin/service nsdaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del nsdaemon
fi
%endif

%package -n castor-policies
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: perl
%description -n castor-policies
castor (Cern Advanced STORage system) - Policies used by the expert system
%files -n castor-policies
%defattr(-,root,root)
%attr(0644,root,bin) /etc/castor/expert/migrator.pl
%attr(0644,root,bin) /etc/castor/expert/migratorRetryPolicy.pl
%attr(0644,root,bin) /etc/castor/expert/recaller.pl
%attr(0644,root,bin) /etc/castor/expert/recallerRetryPolicy.pl
%attr(0644,root,bin) /etc/castor/expert/replica.pl

%package -n castor-rfio-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-rfio-client
castor (Cern Advanced STORage system) - RFIO clients
%files -n castor-rfio-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rfcat.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfchmod.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfcp.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfdir.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfmkdir.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfrename.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfrm.1castor
%attr(0755,root,bin) /usr/bin/rfcat
%attr(0755,root,bin) /usr/bin/rfchmod
%attr(0755,root,bin) /usr/bin/rfcp
%attr(0755,root,bin) /usr/bin/rfdir
%attr(0755,root,bin) /usr/bin/rfmkdir
%attr(0755,root,bin) /usr/bin/rfrename
%attr(0755,root,bin) /usr/bin/rfrm
%attr(0755,root,bin) /usr/bin/rfstat

%package -n castor-rfio-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,vdt_globus_essentials
%description -n castor-rfio-server
castor (Cern Advanced STORage system) - RFIO server
%files -n castor-rfio-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-rfio-server
%attr(0644,root,bin) %doc /usr/share/man/man1/rfiod.1castor
%attr(-,root,bin) %dir /var/spool/rfio
%attr(0755,root,bin) /etc/init.d/rfiod
%attr(0644,root,bin) /etc/sysconfig/rfiod.example
%attr(0755,root,bin) /usr/bin/rfiod
%post -n castor-rfio-server
/sbin/chkconfig --add rfiod
/sbin/service rfiod condrestart > /dev/null 2>&1 || :
%preun -n castor-rfio-server
if [ "$1" = 0 ]; then
    /sbin/service rfiod stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rfiod
fi

%if %has_oracle
%package -n castor-rh-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle,vdt_globus_essentials
%description -n castor-rh-server
castor (Cern Advanced STORage system) - Request Handler server
%files -n castor-rh-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-rh-server
%attr(0644,root,bin) %doc /usr/share/man/man1/rhserver.1castor
%attr(-,root,bin) %dir /var/spool/rhserver
%attr(0755,root,bin) /etc/init.d/rhserver
%attr(0644,root,bin) /etc/sysconfig/rhserver.example
%attr(0750,root,bin) /usr/bin/rhserver
%post -n castor-rh-server
/sbin/chkconfig --add rhserver
/sbin/service rhserver condrestart > /dev/null 2>&1 || :
%preun -n castor-rh-server
if [ "$1" = 0 ]; then
    /sbin/service rhserver stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rhserver
fi
%endif

%if %has_oracle
%package -n castor-repack-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle
%description -n castor-repack-server
castor (Cern Advanced STORage system) - Repack server
%files -n castor-repack-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-repack-server
%attr(0644,root,bin) %doc /usr/share/man/man1/repackserver.1castor
%attr(-,root,bin) %dir /var/spool/repack
%attr(0640,root,st) /etc/castor/ORAREPACKCONFIG.example
%attr(0755,root,bin) /etc/init.d/repackserver
%attr(0644,root,bin) /etc/sysconfig/repackserver.example
%attr(0750,root,bin) /usr/bin/repackserver
%post -n castor-repack-server
/sbin/chkconfig --add repackserver
/sbin/service repackserver condrestart > /dev/null 2>&1 || :
/bin/chown stage:st /var/spool/repack
/bin/chown stage:st /var/spool/repack/log > /dev/null 2>&1
%preun -n castor-repack-server
if [ "$1" = 0 ]; then
    /sbin/service repackserver stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del repackserver
fi
%endif

%if %has_oracle
%package -n castor-repack-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-repack-client
castor (Cern Advanced STORage system) - Repack client
%files -n castor-repack-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/repack.1castor
%attr(0755,root,bin) /usr/bin/repack
%endif

%package -n castor-rmc-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-rmc-server
castor (Cern Advanced STORage system) - Remote Media Controller server
%files -n castor-rmc-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-rmc-server
%attr(0644,root,bin) %doc /usr/share/man/man1/rmcdaemon.1castor
%attr(-,root,bin) %dir /var/spool/rmc
%attr(0755,root,bin) /etc/init.d/rmcdaemon
%attr(0644,root,bin) /etc/sysconfig/rmcdaemon.example
%attr(0750,root,root) /usr/bin/rmcdaemon
%post -n castor-rmc-server
/sbin/chkconfig --add rmcdaemon
/sbin/service rmcdaemon condrestart > /dev/null 2>&1 || :
%preun -n castor-rmc-server
if [ "$1" = 0 ]; then
    /sbin/service rmcdaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rmcdaemon
fi

%package -n castor-rmmaster-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib-monitor
%description -n castor-rmmaster-client
castor (Cern Advanced STORage system) - Resource Monitoring Master clients
%files -n castor-rmmaster-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rmAdminNode.1castor
%attr(0755,root,bin) /usr/bin/rmAdminNode

%if %has_oracle
%if %has_lsf
%package -n castor-rmmaster-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-monitor
%description -n castor-rmmaster-server
castor (Cern Advanced STORage system) - Resource Monitoring Master server
%files -n castor-rmmaster-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-rmmaster-server
%attr(-,root,bin) %dir /var/spool/rmmaster
%attr(0755,root,bin) /etc/init.d/rmMasterDaemon
%attr(0644,root,bin) /etc/sysconfig/rmMasterDaemon.example
%attr(0750,root,bin) /usr/bin/rmMasterDaemon
%attr(0755,root,bin) /usr/bin/rmGetNodes
%post -n castor-rmmaster-server
/sbin/chkconfig --add rmMasterDaemon
/sbin/service rmMasterDaemon condrestart > /dev/null 2>&1 || :
%preun -n castor-rmmaster-server
if [ "$1" = 0 ]; then
    /sbin/service rmMasterDaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rmMasterDaemon
fi
%endif
%endif

%package -n castor-rmnode-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-monitor
%description -n castor-rmnode-server
castor (Cern Advanced STORage system) - Resource Monitoring running on each worker node
%files -n castor-rmnode-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-rmnode-server
%attr(-,root,bin) %dir /var/spool/rmnode
%attr(0755,root,bin) /etc/init.d/rmNodeDaemon
%attr(0644,root,bin) /etc/sysconfig/rmNodeDaemon.example
%attr(0750,root,bin) /usr/bin/rmNodeDaemon
%post -n castor-rmnode-server
/sbin/chkconfig --add rmNodeDaemon
/sbin/service rmNodeDaemon condrestart > /dev/null 2>&1 || :
%preun -n castor-rmnode-server
if [ "$1" = 0 ]; then
    /sbin/service rmNodeDaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rmNodeDaemon
fi

%package -n castor-rtcopy-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-rtcopy-messages
%description -n castor-rtcopy-client
castor (Cern Advanced STORage system) - Remote Tape Copy clients
%files -n castor-rtcopy-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rtstat.1castor
%attr(0755,root,bin) /usr/bin/rtstat

%package -n castor-rtcopy-messages
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-rtcopy-messages
castor (Cern Advanced STORage system) - Remote Tape Copy messages
%files -n castor-rtcopy-messages
%defattr(-,root,root)
%ifarch x86_64
%attr(0644,root,bin) /usr/lib64/rtcopy/err_messages
%else
%attr(0644,root,bin) /usr/lib/rtcopy/err_messages
%endif

%package -n castor-rtcopy-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-rtcopy-server
castor (Cern Advanced STORage system) - Remote Tape Copy server running on a tape server
%files -n castor-rtcopy-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-rtcopy-server
%attr(0644,root,bin) %doc /usr/share/man/man1/killjid.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rtcpd.1castor
%attr(-,root,bin) %dir /var/spool/rtcopy
%attr(-,root,bin) %dir /var/lib/castor
%attr(0755,root,bin) /etc/init.d/rtcpd
%attr(0644,root,bin) /etc/sysconfig/rtcpd.example
%attr(0750,root,root) /usr/bin/killjid
%attr(0750,root,bin) /usr/bin/rtcpd
%post -n castor-rtcopy-server
/sbin/chkconfig --add rtcpd
/sbin/service rtcpd condrestart > /dev/null 2>&1 || :
%preun -n castor-rtcopy-server
if [ "$1" = 0 ]; then
    /sbin/service rtcpd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rtcpd
fi

%if %has_oracle
%package -n castor-rtcopy-clientserver
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle
%description -n castor-rtcopy-clientserver
castor (Cern Advanced STORage system) - Remote Tape Copy Client Server running on top of a database. - This will generate raw RTCOPY commands understood by the rtcopy-server - running on tape server.
%files -n castor-rtcopy-clientserver
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-rtcopy-clientserver
%attr(0644,root,bin) %doc /usr/share/man/man1/rtcpclientd.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rtcpcldCleanupDB.1castor
%attr(-,root,bin) %dir /var/spool/rtcpclientd
%attr(0755,root,bin) /etc/init.d/rtcpclientd
%attr(0755,root,bin) /usr/bin/TapeErrorHandler
%attr(0755,root,bin) /usr/bin/migrator
%attr(0755,root,bin) /usr/bin/recaller
%attr(0750,root,bin) /usr/bin/rtcpcldCleanupDB
%attr(0750,root,bin) /usr/bin/rtcpclientd
%post -n castor-rtcopy-clientserver
/sbin/chkconfig --add rtcpclientd
/bin/chown stage:st /var/spool/rtcpclientd
/sbin/service rtcpclientd condrestart > /dev/null 2>&1 || :%preun -n castor-rtcopy-clientserver
if [ "$1" = 0 ]; then
    /sbin/service rtcpclientd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rtcpclientd
fi
%endif

%package -n castor-stager-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Obsoletes: castor-commands,castor-doc
%description -n castor-stager-client
castor (Cern Advanced STORage system) - Stager clients
%files -n castor-stager-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_get.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_update.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_put.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_putdone.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_qry.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_rm.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_setfilegcweight.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_addprivilege.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_removeprivilege.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_listprivileges.1castor
%attr(0755,root,bin) /usr/bin/stager_get
%attr(0755,root,bin) /usr/bin/stager_update
%attr(0755,root,bin) /usr/bin/stager_put
%attr(0755,root,bin) /usr/bin/stager_putdone
%attr(0755,root,bin) /usr/bin/stager_qry
%attr(0755,root,bin) /usr/bin/stager_rm
%attr(0755,root,bin) /usr/bin/stager_setfilegcweight
%attr(0755,root,bin) /usr/bin/stager_addprivilege
%attr(0755,root,bin) /usr/bin/stager_removeprivilege
%attr(0755,root,bin) /usr/bin/stager_listprivileges
%attr(0755,root,bin) /usr/bin/castor

%package -n castor-stager-clientold
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-stager-clientold
castor (Cern Advanced STORage system) - Old Stager clients to access SHIFT/CASTORv1 stager daemon
%files -n castor-stager-clientold
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/stage.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stage_other_options.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stagealloc.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stagecat.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stagechng.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stageclr.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stageget.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stagein.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stageout.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stageping.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stageput.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stageqry.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stagestat.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stageupdc.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stagewrt.1castor
%attr(0644,root,bin) %doc /usr/share/man/man3/print_stcp.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/print_stpp.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rc_castor2shift.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_alloc.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_api.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_clr_Disk.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_clr_Hsm.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_clr_Link.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_clr_Path.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_clr_Tape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_constants.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_get.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_getcallback.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_geterrbuf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_getlog.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_getoutbuf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_in_disk.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_in_hsm.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_in_tape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_kill.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_limits.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_macros.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_out_disk.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_out_hsm.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_out_tape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_ping.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_put_hsm.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_qry_Disk.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_qry_Hsm.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_qry_Tape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_setcallback.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_seterrbuf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_setlog.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_setoutbuf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_struct.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_updc.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_wrt_disk.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_wrt_hsm.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/stage_wrt_tape.3castor
%attr(0755,root,bin) /usr/bin/stagealloc
%attr(0755,root,bin) /usr/bin/stagecat
%attr(0755,root,bin) /usr/bin/stagechng
%attr(0755,root,bin) /usr/bin/stageclr
%attr(0755,root,bin) /usr/bin/stageget
%attr(0755,root,bin) /usr/bin/stagein
%attr(0755,root,bin) /usr/bin/stageout
%attr(0755,root,bin) /usr/bin/stageping
%attr(0755,root,bin) /usr/bin/stageput
%attr(0755,root,bin) /usr/bin/stageqry
%attr(0755,root,bin) /usr/bin/stagestat
%attr(0755,root,bin) /usr/bin/stageupdc
%attr(0755,root,bin) /usr/bin/stagewrt

%if %has_oracle
%package -n castor-stager-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle
%description -n castor-stager-server
castor (Cern Advanced STORage system) - Stager server
%files -n castor-stager-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-stager-server
%attr(-,root,bin) %dir /var/spool/stager
%attr(0755,root,bin) /etc/init.d/stager
%attr(0644,root,bin) /etc/sysconfig/stager.example
%attr(0750,root,bin) /usr/bin/stagerDaemon
%post -n castor-stager-server
/sbin/chkconfig --add stager
/sbin/service stager condrestart > /dev/null 2>&1 || :
%preun -n castor-stager-server
if [ "$1" = 0 ]; then
    /sbin/service stager stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del stager
fi
%endif

%package -n castor-sysconfig
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-sysconfig
castor (Cern Advanced STORage system) - Configuration files read by every server
%files -n castor-sysconfig
%defattr(-,root,root)
%attr(0644,root,bin) /etc/sysconfig/castor.example
%attr(0644,root,bin) /etc/sysconfig/castor_compiler.example
%attr(0644,root,bin) /etc/sysconfig/castor_db.example
%attr(0644,root,bin) /etc/sysconfig/castor_env.example
%attr(0644,root,bin) /etc/sysconfig/castor_paths.example

%package -n castor-tape-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-tape-client
castor (Cern Advanced STORage system) - Tape clients
%files -n castor-tape-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/dumptape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpread.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tprstat.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpstat.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpusage.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpwrite.1castor
%attr(0755,root,bin) /usr/bin/dumptape
%attr(0755,root,bin) /usr/bin/tpconfig
%attr(0755,root,bin) /usr/bin/tpread
%attr(0755,root,bin) /usr/bin/tprstat
%attr(0755,root,bin) /usr/bin/tpstat
%attr(0755,root,bin) /usr/bin/tpusage
%attr(0755,root,bin) /usr/bin/tpwrite

%if %has_stk_ssi
%package -n castor-tape-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-tape-server
castor (Cern Advanced STORage system) - Tape server
%files -n castor-tape-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-tape-server
%attr(0644,root,bin) %doc /usr/share/man/man1/smc.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tape_oper.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpconfig.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpdaemon.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tplabel.1castor
%attr(-,root,bin) %dir /var/spool/tape
%attr(0640,root,st) /etc/castor/TPCONFIG.example
%attr(0755,root,bin) /etc/init.d/tpdaemon
%attr(0644,root,bin) /etc/sysconfig/tpdaemon.example
%attr(0750,root,root) /usr/bin/confdrive
%attr(0750,root,root) /usr/bin/mounttape
%attr(0750,root,root) /usr/bin/posovl
%attr(0750,root,root) /usr/bin/rlstape
%attr(6755,root,bin) /usr/bin/smc
%attr(0750,root,root) /usr/bin/tpdaemon
%attr(0755,root,bin) /usr/bin/tpdump
%attr(0755,root,bin) /usr/bin/tplabel
%post -n castor-tape-server
/sbin/chkconfig --add tpdaemon
/sbin/service tpdaemon condrestart > /dev/null 2>&1 || :
%preun -n castor-tape-server
if [ "$1" = 0 ]; then
    /sbin/service tpdaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del tpdaemon
fi
%endif

%package -n castor-upv-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-upv-client
castor (Cern Advanced STORage system) - User Privilege clients
%files -n castor-upv-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvadd.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvcheck.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvdelete.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvlist.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvmodify.1castor
%attr(0755,root,bin) /usr/bin/Cupvadd
%attr(0755,root,bin) /usr/bin/Cupvcheck
%attr(0755,root,bin) /usr/bin/Cupvdelete
%attr(0755,root,bin) /usr/bin/Cupvlist
%attr(0755,root,bin) /usr/bin/Cupvmodify

%if %has_oracle
%package -n castor-upv-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-upv-server
castor (Cern Advanced STORage system) - User Privilege server
%files -n castor-upv-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-upv-server
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvdaemon.1castor
%attr(-,root,bin) %dir /var/spool/upv
%attr(0640,root,st) /etc/castor/CUPVCONFIG.example
%attr(0755,root,bin) /etc/init.d/Cupvdaemon
%attr(0644,root,bin) /etc/sysconfig/Cupvdaemon.example
%attr(0750,root,bin) /usr/bin/Cupvdaemon
%post -n castor-upv-server
/sbin/chkconfig --add Cupvdaemon
/sbin/service Cupvdaemon condrestart > /dev/null 2>&1 || :
%preun -n castor-upv-server
if [ "$1" = 0 ]; then
    /sbin/service Cupvdaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del Cupvdaemon
fi
%endif

%package -n castor-vdqm2-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Obsoletes: castor-vdqm-client
%description -n castor-vdqm2-client
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager clients version 2
%files -n castor-vdqm2-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/showqueues.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpsrv_in_prod.1castor
%attr(0755,root,bin) /usr/bin/showqueues
%attr(0750,root,bin) /usr/bin/tpsrv_in_prod
%attr(0755,root,bin) /usr/bin/vdqm_admin

%if %has_oracle
%package -n castor-vdqm2-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle,castor-vdqm2-lib-oracle
Obsoletes: castor-vdqm-server
%description -n castor-vdqm2-server
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager server version 2
%files -n castor-vdqm2-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-vdqm2-server
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmserver.1castor
%attr(-,root,bin) %dir /var/spool/vdqm
%attr(0755,root,bin) /etc/init.d/vdqmserver
%attr(0644,root,bin) /etc/sysconfig/vdqmserver.example
%attr(0750,root,bin) /usr/bin/vdqmserver
%attr(0640,root,root) /etc/castor/ORAVDQMCONFIG.example
%post -n castor-vdqm2-server
/sbin/chkconfig --add vdqmserver
/sbin/service vdqmserver condrestart > /dev/null 2>&1 || :
%preun -n castor-vdqm2-server
if [ "$1" = 0 ]; then
    /sbin/service vdqmserver stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del vdqmserver
fi
%endif

%if %has_oracle
%package -n castor-vdqm2-lib-oracle
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-vdqm2-lib-oracle
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager server version 2 library
%files -n castor-vdqm2-lib-oracle
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastorVdqmOra.so.2.1
%attr(-,root,root) /usr/lib64/libcastorVdqmOra.so.2.1.8.10
%else
%attr(-,root,root) /usr/lib/libcastorVdqmOra.so.2.1
%attr(-,root,root) /usr/lib/libcastorVdqmOra.so.2.1.8.10
%endif
%endif

%package -n castor-vmgr-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-vmgr-client
castor (Cern Advanced STORage system) - Volume Manager clients
%files -n castor-vmgr-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgr.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletedenmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletedgnmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletelibrary.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletemodel.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletepool.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletetape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeltag.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterdenmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterdgnmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterlibrary.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrentermodel.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterpool.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrentertape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrgettag.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistdenmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistdgnmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistlibrary.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistmodel.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistpool.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlisttape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifylibrary.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifypool.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifytape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrsettag.1castor
%attr(0755,root,bin) /usr/bin/vmgrdeletedenmap
%attr(0755,root,bin) /usr/bin/vmgrdeletedgnmap
%attr(0755,root,bin) /usr/bin/vmgrdeletelibrary
%attr(0755,root,bin) /usr/bin/vmgrdeletemodel
%attr(0755,root,bin) /usr/bin/vmgrdeletepool
%attr(0755,root,bin) /usr/bin/vmgrdeletetape
%attr(0755,root,bin) /usr/bin/vmgrdeltag
%attr(0755,root,bin) /usr/bin/vmgrenterdenmap
%attr(0755,root,bin) /usr/bin/vmgrenterdgnmap
%attr(0755,root,bin) /usr/bin/vmgrenterlibrary
%attr(0755,root,bin) /usr/bin/vmgrentermodel
%attr(0755,root,bin) /usr/bin/vmgrenterpool
%attr(0755,root,root) /usr/bin/vmgrentertape
%attr(0755,root,bin) /usr/bin/vmgrgettag
%attr(0755,root,bin) /usr/bin/vmgrlistdenmap
%attr(0755,root,bin) /usr/bin/vmgrlistdgnmap
%attr(0755,root,bin) /usr/bin/vmgrlistlibrary
%attr(0755,root,bin) /usr/bin/vmgrlistmodel
%attr(0755,root,bin) /usr/bin/vmgrlistpool
%attr(0755,root,bin) /usr/bin/vmgrlisttape
%attr(0755,root,root) /usr/bin/vmgrmodifylibrary
%attr(0755,root,root) /usr/bin/vmgrmodifypool
%attr(0755,root,root) /usr/bin/vmgrmodifytape
%attr(0755,root,bin) /usr/bin/vmgrsettag

%if %has_oracle
%package -n castor-vmgr-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-vmgr-server
castor (Cern Advanced STORage system) - Volume Manager server
%files -n castor-vmgr-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-vmgr-server
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdaemon.1castor
%attr(-,root,bin) %dir /var/spool/vmgr
%attr(0640,root,st) /etc/castor/VMGRCONFIG.example
%attr(0755,root,bin) /etc/init.d/vmgrdaemon
%attr(0644,root,bin) /etc/sysconfig/vmgrdaemon.example
%attr(0750,root,bin) /usr/bin/vmgrdaemon
%post -n castor-vmgr-server
/sbin/chkconfig --add vmgrdaemon
/sbin/service vmgrdaemon condrestart > /dev/null 2>&1 || :
%preun -n castor-vmgr-server
if [ "$1" = 0 ]; then
    /sbin/service vmgrdaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del vmgrdaemon
fi
%endif

%package -n castor-dlf-web
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: php-oci8
%description -n castor-dlf-web
castor (Cern Advanced STORage system) - Distributed Logging Facility Web Interface
%files -n castor-dlf-web
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/www/html/dlf
%attr(-,root,bin) %dir /var/www/html/dlf/db
%attr(-,root,bin) %dir /var/www/html/dlf/images
%attr(-,root,bin) %dir /var/www/html/dlf/js
%attr(0644,root,bin) /var/www/html/dlf/config.php
%attr(0644,root,bin) /var/www/html/dlf/dbview.php
%attr(0644,root,bin) /var/www/html/dlf/index.php
%attr(0640,root,apache) /var/www/conf/dlf/login.conf.example
%attr(0644,root,bin) /var/www/html/dlf/query.php
%attr(0644,root,bin) /var/www/html/dlf/results.php
%attr(0644,root,bin) /var/www/html/dlf/site.css
%attr(0644,root,bin) /var/www/html/dlf/utils.php
%attr(0644,root,bin) /var/www/html/dlf/db/oracle.php
%attr(0644,root,bin) /var/www/html/dlf/js/CalendarPopup.js
%attr(0644,root,bin) /var/www/html/dlf/js/Date.js
%attr(0644,root,bin) /var/www/html/dlf/images/backdrop.png
%attr(0644,root,bin) /var/www/html/dlf/images/css.png
%attr(0644,root,bin) /var/www/html/dlf/images/php.png
%attr(0644,root,bin) /var/www/html/dlf/images/xhtml.png

%package -n castor-lib-monitor
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib
%description -n castor-lib-monitor
castor (Cern Advanced STORage system) - Shared libraries for monitoring framework
%files -n castor-lib-monitor
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastorMonitor.so.2.1
%attr(-,root,root) /usr/lib64/libcastorMonitor.so.2.1.8.10
%else
%attr(-,root,root) /usr/lib/libcastorMonitor.so.2.1
%attr(-,root,root) /usr/lib/libcastorMonitor.so.2.1.8.10
%endif
%post -n castor-lib-monitor -p /sbin/ldconfig
%postun -n castor-lib-monitor -p /sbin/ldconfig

%if %has_globus
%package -n castor-gridftp-dsi-common
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-gridftp-dsi-common
castor (Cern Advanced STORage system) - Commonnalities between internal and external CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-common
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-gridftp-dsi-common
%endif

%if %has_globus
%package -n castor-gridftp-dsi-int
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: vdt_globus_data_server,vdt_globus_essentials,castor-gridftp-dsi-common
%description -n castor-gridftp-dsi-int
castor (Cern Advanced STORage system) - Internal CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-int
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log
%ifarch x86_64
%attr(0755,root,bin) /opt/globus/lib/libglobus_gridftp_server_CASTOR2int_gcc64dbg.so
%else
%attr(0755,root,bin) /opt/globus/lib/libglobus_gridftp_server_CASTOR2int_gcc32dbg.so
%endif
%post -n castor-gridftp-dsi-int
/bin/touch /var/log/gridftp.log
/bin/touch /var/log/globus-gridftp.log
/bin/chown stage:st /var/log/gridftp.log
/bin/chown stage:st /var/log/globus-gridftp.log
%endif

%if %has_globus
%package -n castor-gridftp-dsi-ext
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib,xinetd,vdt_globus_data_server,vdt_globus_essentials,castor-gridftp-dsi-common
%description -n castor-gridftp-dsi-ext
castor (Cern Advanced STORage system) - External CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-ext
%defattr(-,root,root)
%config(noreplace) /etc/xinetd.d/gsiftp
%attr(-,root,bin) %dir /var/log
%ifarch x86_64
%attr(0755,root,bin) /opt/globus/lib/libglobus_gridftp_server_CASTOR2ext_gcc64dbg.so
%else
%attr(0755,root,bin) /opt/globus/lib/libglobus_gridftp_server_CASTOR2ext_gcc32dbg.so
%endif
%post -n castor-gridftp-dsi-ext
if [ "`grep gsiftp /etc/services`" = "" ]; then 
    echo "gsiftp          2811/tcp # gridftp server port" >> /etc/services
fi
/sbin/service xinetd condrestart > /dev/null 2>&1 || :
%postun -n castor-gridftp-dsi-ext
/sbin/service xinetd reload > /dev/null 2>&1 || :
%endif

%if %has_oracle
%package -n castor-lib-policy
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib
%description -n castor-lib-policy
castor (Cern Advanced STORage system) - Shared libraries for the policy framework
%files -n castor-lib-policy
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastorInfoPolicy.so.2.1
%attr(-,root,root) /usr/lib64/libcastorInfoPolicy.so.2.1.8.10
%else
%attr(-,root,root) /usr/lib/libcastorInfoPolicy.so.2.1
%attr(-,root,root) /usr/lib/libcastorInfoPolicy.so.2.1.8.10
%endif
%post -n castor-lib-policy -p /sbin/ldconfig
%postun -n castor-lib-policy -p /sbin/ldconfig
%endif

%if %has_oracle
%package -n castor-mighunter-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-policy
%description -n castor-mighunter-server
castor (Cern Advanced STORage system) - Migration Hunter Daemon
%files -n castor-mighunter-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-mighunter-server
%attr(0644,root,bin) %doc /usr/share/man/man1/migHunterDaemon.1castor
%attr(-,root,bin) %dir /var/spool/mighunter
%attr(0755,root,bin) /etc/init.d/mighunter
%attr(0644,root,bin) /etc/sysconfig/mighunter.example
%attr(0750,root,root) /usr/bin/migHunterDaemon
%attr(0644,root,bin) /etc/castor/policies/migration.py.example
%attr(0644,root,bin) /etc/castor/policies/stream.py.example
%post -n castor-mighunter-server
/sbin/chkconfig --add mighunter
/sbin/service mighunter condrestart > /dev/null 2>&1 || :
%preun -n castor-mighunter-server
if [ "$1" = 0 ]; then
    /sbin/service mighunter stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del mighunter
fi
%endif

%if %has_oracle
%package -n castor-rechandler-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-policy
%description -n castor-rechandler-server
castor (Cern Advanced STORage system) - Recall Handler Daemon
%files -n castor-rechandler-server
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-rechandler-server
%attr(0644,root,bin) %doc /usr/share/man/man1/recHandlerDaemon.1castor
%attr(-,root,bin) %dir /var/spool/rechandler
%attr(0755,root,bin) /etc/init.d/rechandler
%attr(0644,root,bin) /etc/sysconfig/rechandler.example
%attr(0644,root,bin) /etc/castor/policies/rechandler.py.example
%attr(0750,root,root) /usr/bin/recHandlerDaemon
%post -n castor-rechandler-server
/sbin/chkconfig --add rechandler
/sbin/service rechandler condrestart > /dev/null 2>&1 || :
%preun -n castor-rechandler-server
if [ "$1" = 0 ]; then
    /sbin/service rechandler stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rechandler
fi
%endif

%package -n castor-csec
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib,vdt_globus_essentials,glite-security-voms-api-c
%description -n castor-csec
castor (Cern Advanced STORage system) - Csec library
%files -n castor-csec
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI.so.2.1
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI.so
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI_thread.so.2.1
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI_thread.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI_thread.so
%attr(-,root,root) /usr/lib64/libCsec_plugin_ID.so.2.1
%attr(-,root,root) /usr/lib64/libCsec_plugin_ID.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libCsec_plugin_ID.so
%attr(-,root,root) /usr/lib64/libCsec_plugin_KRB5.so.2.1
%attr(-,root,root) /usr/lib64/libCsec_plugin_KRB5.so.2.1.8.10
%attr(-,root,root) /usr/lib64/libCsec_plugin_KRB5.so
%else
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI.so.2.1
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI.so.2.1.8.10
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI.so
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI_thread.so.2.1
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI_thread.so.2.1.8.10
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI_thread.so
%attr(-,root,root) /usr/lib/libCsec_plugin_ID.so.2.1
%attr(-,root,root) /usr/lib/libCsec_plugin_ID.so.2.1.8.10
%attr(-,root,root) /usr/lib/libCsec_plugin_ID.so
%attr(-,root,root) /usr/lib/libCsec_plugin_KRB5.so.2.1
%attr(-,root,root) /usr/lib/libCsec_plugin_KRB5.so.2.1.8.10
%attr(-,root,root) /usr/lib/libCsec_plugin_KRB5.so
%endif

%else
%package -n castor-tape-server-nostk
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-tape-server-nostk
castor (Cern Advanced STORage system) - Tape server
%files -n castor-tape-server-nostk
%defattr(-,root,root)
%config(noreplace) /etc/logrotate.d/castor-tape-server
%attr(0644,root,bin) %doc /usr/share/man/man1/smc.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tape_oper.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpconfig.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpdaemon.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tplabel.1castor
%attr(-,root,bin) %dir /var/spool/tape
%attr(0640,root,st) /etc/castor/TPCONFIG.example
%attr(0755,root,bin) /etc/init.d/tpdaemon
%attr(0644,root,bin) /etc/sysconfig/tpdaemon.example
%attr(0750,root,root) /usr/bin/confdrive
%attr(0750,root,root) /usr/bin/mounttape
%attr(0750,root,root) /usr/bin/posovl
%attr(0750,root,root) /usr/bin/rlstape
%attr(6755,root,bin) /usr/bin/smc
%attr(0750,root,root) /usr/bin/tpdaemon
%attr(0755,root,bin) /usr/bin/tpdump
%attr(0755,root,bin) /usr/bin/tplabel
%post -n castor-tape-server-nostk
/sbin/chkconfig --add tpdaemon
/sbin/service tpdaemon condrestart > /dev/null 2>&1 || :
%preun -n castor-tape-server-nostk
if [ "$1" = 0 ]; then
    /sbin/service tpdaemon stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del tpdaemon
fi

%endif
